import React from 'react'
import GridWithOpenbis from '@src/js/components/common/grid/GridWithOpenbis.jsx'
import GridUtil from '@src/js/components/common/grid/GridUtil.js'
import GridExportOptions from '@src/js/components/common/grid/GridExportOptions.js'
import EntityTypeLink from '@src/js/components/common/link/EntityTypeLink.jsx'
import PluginLink from '@src/js/components/common/link/PluginLink.jsx'
import openbis from '@src/js/services/openbis.js'
import messages from '@src/js/common/messages.js'
import logger from '@src/js/common/logger.js'

class EntityTypesGrid extends React.PureComponent {
  render() {
    logger.log(logger.DEBUG, 'EntityTypesGrid.render')

    const {
      id,
      rows,
      exportable,
      selectedRowId,
      onSelectedRowChange,
      controllerRef
    } = this.props

    return (
      <GridWithOpenbis
        id={id}
        settingsId={id}
        controllerRef={controllerRef}
        header={this.getHeader()}
        columns={this.getColumns()}
        rows={rows}
        sort='code'
        exportable={exportable}
        selectable={true}
        selectedRowId={selectedRowId}
        onSelectedRowChange={onSelectedRowChange}
      />
    )
  }

  getHeader() {
    const { kind } = this.props

    if (kind === openbis.EntityKind.EXPERIMENT) {
      return messages.get(messages.COLLECTION_TYPES)
    } else if (kind === openbis.EntityKind.SAMPLE) {
      return messages.get(messages.OBJECT_TYPES)
    } else if (kind === openbis.EntityKind.DATA_SET) {
      return messages.get(messages.DATA_SET_TYPES)
    } else if (kind === openbis.EntityKind.MATERIAL) {
      return messages.get(messages.MATERIAL_TYPES)
    }
  }

  getColumns() {
    const { kind } = this.props
    const columns = []

    columns.push({
      name: 'code',
      label: messages.get(messages.CODE),
      exportableField: GridExportOptions.EXPORTABLE_FIELD.CODE,
      getValue: ({ row }) => row.code,
      renderValue: ({ row }) => {
        return <EntityTypeLink typeCode={row.code} typeKind={kind} />
      }
    })

    columns.push({
      name: 'description',
      label: messages.get(messages.DESCRIPTION),
      exportableField: GridExportOptions.EXPORTABLE_FIELD.DESCRIPTION,
      getValue: ({ row }) => row.description
    })

    columns.push({
      name: 'validationPlugin',
      label: messages.get(messages.VALIDATION_PLUGIN),
      exportableField: GridExportOptions.EXPORTABLE_FIELD.VALIDATION_PLUGIN,
      getValue: ({ row }) => row.validationPlugin,
      renderValue: ({ value }) => {
        return (
          <PluginLink
            pluginName={value}
            pluginType={openbis.PluginType.ENTITY_VALIDATION}
          />
        )
      }
    })

    if (kind === openbis.EntityKind.SAMPLE) {
      columns.push({
        name: 'generatedCodePrefix',
        label: messages.get(messages.GENERATED_CODE_PREFIX),
        exportableField:
          GridExportOptions.EXPORTABLE_FIELD.GENERATED_CODE_PREFIX,
        getValue: ({ row }) => row.generatedCodePrefix
      })

      columns.push({
        name: 'autoGeneratedCode',
        label: messages.get(messages.GENERATE_CODES),
        exportableField: GridExportOptions.EXPORTABLE_FIELD.GENERATE_CODES,
        getValue: ({ row }) => row.autoGeneratedCode
      })

      columns.push({
        name: 'subcodeUnique',
        label: messages.get(messages.SUBCODES_UNIQUE),
        exportableField: GridExportOptions.EXPORTABLE_FIELD.UNIQUE_SUBCODES,
        getValue: ({ row }) => row.subcodeUnique
      })
    }

    if (kind === openbis.EntityKind.DATA_SET) {
      columns.push({
        name: 'mainDataSetPattern',
        label: messages.get(messages.MAIN_DATA_SET_PATTERN),
        exportableField:
          GridExportOptions.EXPORTABLE_FIELD.MAIN_DATA_SET_PATTERN,
        getValue: ({ row }) => row.mainDataSetPattern
      })

      columns.push({
        name: 'mainDataSetPath',
        label: messages.get(messages.MAIN_DATA_SET_PATH),
        exportableField: GridExportOptions.EXPORTABLE_FIELD.MAIN_DATA_SET_PATH,
        getValue: ({ row }) => row.mainDataSetPath
      })

      columns.push({
        name: 'disallowDeletion',
        label: messages.get(messages.DISALLOW_DELETION),
        exportableField: GridExportOptions.EXPORTABLE_FIELD.DISALLOW_DELETION,
        getValue: ({ row }) => row.disallowDeletion
      })
    }

    columns.push(GridUtil.modificationDateColumn({ path: 'modificationDate' }))

    return columns
  }
}

export default EntityTypesGrid
